@@ -134,7 +134,7 @@ def merge_mges(mges, merge_interval):
 
 def create_mge_gff_file(genome_file_path, file_format, mges):
   record = SeqIO.read(genome_file_path, file_format)
-  gff_file_path = Path(genome_file_path).with_suffix('.gff')
+  gff_file_path = Path(genome_file_path).with_suffix('_mge.gff')
   with open(gff_file_path, "w") as gff_file:
     for mge in mges:
       gff_file.write(create_gff_line(record.name, mge))
