@@ -49,7 +49,7 @@ def parse_args():
     mask_mges = subparsers.add_parser('mask_mges',
         help='Mask regions from a pseudogenome alignment with the regions in a GFF file produced using the find_mges command'
     )
-    mask_mges.add_argument('-a', '--pseudogenome_alignment_path', help='path to a pseudogenome alignment file', type=lambda x: is_valid_file(parser, x), required=True)
+    mask_mges.add_argument('-f', '--fasta_path', help='path to either a single fasta reference or a pseudogenome alignment file', type=lambda x: is_valid_file(parser, x), required=True)
     mask_mges.add_argument('-g', '--gff_file_path', help='path to a gff file containing MGE regions to be masked', type=lambda x: is_valid_file(parser, x), required=True)
     mask_mges.add_argument('-m', '--masking_character', help='character used to mask (default: N)', default='N')
     
@@ -76,7 +76,7 @@ def main():
         gff_file_path = create_mge_gff_file(options.genome_file_path, options.file_format, merged_mges)
         print(f'GFF file written to {gff_file_path}')
     elif (options.command == 'mask_mges'):
-        masked_alignment_file_path = mask_mges(options.pseudogenome_alignment_path, options.gff_file_path, options.masking_character)
+        masked_alignment_file_path = mask_mges(options.fasta_path, options.gff_file_path, options.masking_character)
         print(f'Masked alignment file written to {masked_alignment_file_path}')
     elif(options.command == 'default_matches'):
         print_default_regex_patterns()
